import Reflux from 'reflux';
import type { LoggerAndTelemetry } from '@mongodb-js/compass-logging';
import type { InternalLayer } from '../modules/geo';
import type { AnalysisState } from '../constants/analysis-states';
import type { CollectionTabPluginMetadata } from '@mongodb-js/compass-collection';
import type { DataService as OriginalDataService } from 'mongodb-data-service';
import type { ActivateHelpers } from 'hadron-app-registry';
import type AppRegistry from 'hadron-app-registry';
import type { Layer, LayerGroup } from 'leaflet';
import type { Schema } from 'mongodb-schema';
export type DataService = Pick<OriginalDataService, 'sample' | 'isCancelError'>;
export type SchemaPluginServices = {
    dataService: DataService;
    localAppRegistry: Pick<AppRegistry, 'on' | 'emit' | 'removeListener' | 'getStore' | 'getRole'>;
    globalAppRegistry: Pick<AppRegistry, 'on' | 'emit' | 'removeListener' | 'getStore'>;
    loggerAndTelemetry: LoggerAndTelemetry;
};
type SchemaState = {
    localAppRegistry: SchemaPluginServices['localAppRegistry'];
    globalAppRegistry: SchemaPluginServices['globalAppRegistry'];
    analysisState: AnalysisState;
    errorMessage: string;
    schema: Schema | null;
    outdated: boolean;
    isActiveTab: boolean;
    resultId: number;
    abortController: undefined | AbortController;
};
type QueryState = {
    filter: Record<string, unknown>;
    limit: number;
    maxTimeMS: number;
    project: null | Record<string, unknown>;
};
export type SchemaStore = Reflux.Store & {
    state: Readonly<SchemaState>;
    setState(state: Partial<SchemaState>): void;
    localAppRegistry: SchemaPluginServices['localAppRegistry'];
    globalAppRegistry: SchemaPluginServices['globalAppRegistry'];
    query: QueryState;
    ns: string;
    geoLayers: Record<string, InternalLayer>;
    dataService: DataService;
    handleSchemaShare(): void;
    onQueryChanged(state: QueryState): void;
    onSubTabChanged(name: string): void;
    onSchemaSampled(): void;
    geoLayerAdded(field: string, layer: Layer): void;
    geoLayersEdited(field: string, layers: LayerGroup): void;
    geoLayersDeleted(layers: LayerGroup): void;
    stopAnalysis(): void;
    _trackSchemaAnalyzed(analysisTimeMS: number): void;
    startAnalysis(): void;
};
export declare function activateSchemaPlugin(options: Pick<CollectionTabPluginMetadata, 'namespace'>, { dataService, localAppRegistry, globalAppRegistry, loggerAndTelemetry, }: SchemaPluginServices, { on, cleanup }: ActivateHelpers): {
    store: SchemaStore;
    actions: any;
    deactivate(): void;
};
export {};
//# sourceMappingURL=store.d.ts.map